/*
 * KernelConf - A Linux Kernel Configuration System
 *
 * Distributed under GNU General Public Lisence
 *
 * Copyright (C) 2002 by Anuradha Ratnaweera
 */

#include <stdio.h>
#include <malloc.h>
#include <string.h>

#include "symbols.h"

/* config symbols are read into a balanced binary tree pointed
 * by SYMBOL_TREE_ROOT.  The first symbol (which is not necessarily
 * the root after a balancing), is FIRST_SYMBOL.  It is also the
 * beginning of a linked list in the order of being read
 */ 
SymbolPtr symbol_tree_root = NULL;
SymbolPtr first_symbol = NULL;

/* Menu items are also kept in a tree in the similar manner to.
 * However, the root menu is kept track of instead of the first
 * read.  The menu hierachy is defined with pointers next,
 * parent and child
 */
MenuPtr menu_tree_root = NULL;
MenuPtr root_menu_item = NULL;

/* Config file names are kept in a linked list to later read
 * help entries
 */
ConfFilePtr first_conf_file = NULL;

long read_help(MenuPtr menu_item, char **buffer)
{
    FILE *conf_file;
    int bufsize, offset;

    if (menu_item->desc_start < 0)
	return -1;

    if ((conf_file = fopen(menu_item->conf_file->name, "rt")) == NULL)
	return 2;

    bufsize = menu_item->desc_length + 1;
    if (menu_item->symbol) {
	offset = strlen(((NodePtr)(menu_item->symbol))->name) + 10;
	bufsize += offset;
    }
    else
	offset = 0;

    (*buffer) = malloc(bufsize);

    if (menu_item->symbol)
	sprintf(*buffer, "\nCONFIG_%s\n\n", ((NodePtr)(menu_item->symbol))->name);

    fseek(conf_file, menu_item->desc_start, SEEK_SET);
    fread((*buffer) + offset, sizeof(char), menu_item->desc_length, conf_file);
    fclose(conf_file);
    (*buffer)[bufsize - 1] = '\n';

    return bufsize;
}

